The SIDD 2.0 DigitalElevationData object
========================================

.. automodule:: sarpy.io.product.sidd2_elements.DigitalElevationData
    :members:
    :show-inheritance:
    :inherited-members:
